from django.test import TestCase
from django.contrib.auth.models import User, Group
from django.conf import settings
from django_openid_auth.models import UserOpenID

from mock import patch


class RequiresTeamTestCase(TestCase):
    def setUp(self):
        self.user = User.objects.create_user('testuser', '', 'test')
        # add user to the right team
        group = Group.objects.create(name='test-team')
        self.user.groups.add(group)
        # fake user logged in via openid
        UserOpenID.objects.create(user=self.user)

    def test_deny_access_to_non_members(self):
        with patch.object(settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS',
                          ['other-team']):
            self.client.login(username='testuser', password='test')
            response = self.client.get('/1/')
        self.assertEqual(response.status_code, 400)
        self.assertTemplateUsed(response, 'sentry/missing_permissions.html')

    def test_allow_access_to_members(self):
        with patch.object(settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS',
                          ['test-team']):
            self.client.login(username='testuser', password='test')
            response = self.client.get('/1/')
        self.assertEqual(response.status_code, 200)

    def test_dont_restrict_teams(self):
        with patch.object(settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS', []):
            self.client.login(username='testuser', password='test')
            response = self.client.get('/1/')
        self.assertEqual(response.status_code, 200)

    def test_dont_restrict_standard_users_if_no_teams(self):
        # remove openid link with user
        UserOpenID.objects.all().delete()

        with patch.object(settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS', []):
            self.client.login(username='testuser', password='test')
            response = self.client.get('/1/')
        self.assertEqual(response.status_code, 200)

    def test_dont_restrict_admin_access_to_staff(self):
        staff = User.objects.create_user('staff', '', 'staff')
        staff.is_staff = True
        staff.save()

        with patch.object(settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS',
                          ['test-team']):
            self.client.login(username='staff', password='staff')
            response = self.client.get('/admin/')
        self.assertEqual(response.status_code, 200)

    def test_dont_restrict_admin_access_to_superuser(self):
        superuser = User.objects.create_user('superuser', '', 'superuser')
        superuser.is_superuser = True
        superuser.save()

        with patch.object(settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS',
                          ['test-team']):
            self.client.login(username='superuser', password='superuser')
            response = self.client.get('/admin/')
        self.assertEqual(response.status_code, 200)

